# frozen_string_literal: true

class Admin::GameSystemsController < AdminController
  before_action :set_game_system, only: [ :show, :edit, :update, :destroy ]
  def index
    @game_systems = GameSystem.all
  end

  def show
  end

  def new
    @game_system = GameSystem.new
  end

  def create
    @game_system = GameSystem.new(game_system_params)
    if @game_system.save
      redirect_to admin_game_system_path(@game_system), notice: t(".success", name: @game_system.name)
    else
      flash.now[:alert] = t(".error", name: @game_system.name)
      render :new, status: :unprocessable_entity
    end
  end

  def edit
  end

  def update
    if @game_system.update(game_system_params)
      redirect_to admin_game_system_path(@game_system), notice: t(".success", name: @game_system.name)
    else
      flash.now[:alert] = t(".error", name: @game_system.name)
      render :edit, status: :unprocessable_entity
    end
  end

  def destroy
    name = @game_system.name
    if @game_system.destroy
      redirect_to admin_game_systems_path, notice: t(".success", name:)
    else
      flash[:alert] = t(".error", name:)
      redirect_to admin_game_systems_path, alert: t(".error")
    end
  end

  private

    def game_system_params
      params.require(:game_system).permit(
        :name,
      )
    end

    def set_game_system
      @game_system = GameSystem.find(params[:id])
    end
end
