# frozen_string_literal: true

Rails.application.routes.draw do
  default_url_options host: "ttcompanion.com"

  root "tables#index"

  get "login" => "sessions#new", as: :login
  delete "logout" => "sessions#destroy", as: :logout

  resources :users, only: [ :new, :create, :show, :edit, :update ] do
    resource :password, only: [ :edit, :update ]
  end
  resources :account_verifications, only: [ :show ]
  resources :password_resets, only: [ :new, :create, :edit, :update ]
  resources :sessions, only: [ :new, :create, :destroy ]

  resources :character_sheet_features do
    member do
      patch :reorder_down
      patch :reorder_up
    end
  end
  resources :character_sheet_sections, only: [ :destroy ] do
    resources :counters, only: [ :new, :create ]
    resources :stats, only: [ :new, :create ]
    resources :text_fields, only: [ :new, :create ]
  end
  resources :characters do
    resources :character_sheet_sections, only: [ :index, :new, :create ]
  end
  resources :counters, only: [ :update, :destroy ]
  resources :stats, only: [ :update, :destroy ]
  resources :table_invites, only: [ :index, :edit, :update ]
  resources :tables do
    resources :characters, only: [] do
      resources :character_sheet_sections, only: [ :index ]
    end
    resources :dice_rolls
    resources :events, only: [ :index ]
    resources :table_invites, only: [ :new, :create ]
  end
  resources :text_fields, only: [ :update, :destroy ]

  resources :admin, only: [ :index ]
  namespace :admin do
    resources :game_systems
  end

  get "up" => "rails/health#show", as: :rails_health_check
  mount MissionControl::Jobs::Engine, at: "/admin/jobs" if Rails.env.production?
end
